<?php

class BackgroundsFrontend {
	var $bg_set = 0;
	var $wp_footer = '';
	function BackgroundsFrontend(){
		add_filter('wp_head',array(&$this,'wp_head'));
		add_filter('wp_footer',array(&$this,'wp_footer'));
		add_filter('wp_head',array(&$this,'update_cookie'));
		add_action('login_head', array(&$this,'login_head'));
	}
	function login_head(){
		$options = get_option('custom_background_options');
		$background_id = isset($options['login'])?intval($options['login']):0;
		if($this->check_background_status($background_id)){
			$this->head_output($background_id);
			return;
		}			
	}
	function wp_head(){
		global $post;
	
		$options = get_option('custom_background_options');		
		if(is_404()){
			$background_id = isset($options['page404'])?intval($options['page404']):0;
			if($this->check_background_status($background_id)){
				$this->head_output($background_id);
				return;
			}
		}else if(is_page()||is_single()){
			$background_id = intval(get_post_meta($post->ID,'custom-background',true));			
			if( $this->check_background_status($background_id) ){	
				$this->head_output($background_id);
				return;
			}

			$categories = get_the_category($post->ID);	
			if(!empty($categories)){
				//look for custom post types with 
				$cats=array();
				foreach($categories as $c){
					$cats[] = $c->term_id;
				}
	
				$args=array(
				   'post_type'=>'background',
				   'taxonomy'=>'category',
				   'cat'=>implode(',',$cats),
				   'posts_per_page'=>1,
				   'post_status'=>'publish'
				);
				$backgrounds = new WP_Query($args);
				$k = 0;
				while($backgrounds->have_posts()) : $backgrounds->the_post();
					$background_id = get_the_ID();	
					if($this->check_background_status($background_id)){
						$this->head_output($background_id);
						return;
					}
				endwhile;			
			}
			
			if(intval($background_id)==0){
				global $wp_version;
				if($wp_version>='3.1.0'&&isset($options['taxonomies'])&&is_array($options['taxonomies'])&&count($options['taxonomies'])>0){
					$post_terms = wp_get_object_terms($post->ID, $options['taxonomies'], array('fields'=>'ids'));
					if(is_array($post_terms)&&count($post_terms)>0){
						$args=array(
						   'post_type'=>'background',
						   'posts_per_page'=>1,
						   'post_status'=>'publish',
						   'tax_query'=>array(
						   	'relation'=>'OR'
						   )
						);
						foreach($options['taxonomies'] as $taxonomy){
							$args['tax_query'][]=array(
								'taxonomy'=>$taxonomy,
								'field'=>'id',
								'terms'=>$post_terms
							);
						}
						$backgrounds = new WP_Query($args);
						$k = 0;
						while($backgrounds->have_posts()) : $backgrounds->the_post();
							$background_id = get_the_ID();	
							if($this->check_background_status($background_id)){
								$this->head_output($background_id);
								return;
							}
						endwhile;																
					}
				}
			}
		}else if(is_category()){
			global $wp_query;
			$cat = $wp_query->get_queried_object();
			$cat_id = $cat->cat_ID;
			$cat_id = $cat_id==0?get_cat_ID(single_cat_title('' , false )):$cat_id;
			if(intval($cat_id)==0){
				$arr = (array)$cat;
				if(isset($arr['term_id'])&&isset($arr['taxonomy'])&&$arr['taxonomy']=='category'){
					$cat_id=$arr['term_id'];
				}
			}
					
			if($cat_id>0){
				$args=array(
				   'post_type'=>'background',
				   'taxonomy'=>'category',
				   'cat'=> $cat_id,
				   'posts_per_page'=>1,
				   'post_status'=>'publish'
				);
				$backgrounds = new WP_Query($args);
				$k = 0;
				while($backgrounds->have_posts()) : $backgrounds->the_post();
					$background_id = get_the_ID();	
					if($this->check_background_status($background_id)){
						$this->head_output($background_id);
						return;
					}
				endwhile;				
			}	
		}else if(is_home()){	
			$background_id = isset($options['home'])?intval($options['home']):0;
			if($this->check_background_status($background_id)){
				$this->head_output($background_id);
				return;
			}
		}else if(is_front_page()){
			$background_id = isset($options['frontpage'])?intval($options['frontpage']):0;
			if($this->check_background_status($background_id)){
				$this->head_output($background_id);
				return;
			}
		}else if(is_search()){
			$background_id = isset($options['search'])?intval($options['search']):0;
			if($this->check_background_status($background_id)){
				$this->head_output($background_id);
				return;
			}
		}else if(is_author()){
			$author_id = get_query_var('author');
			$background_id = intval(get_user_meta($author_id,'custom-background',true));
			$background_id = $background_id==0?(isset($options['author'])?intval($options['author']):0):$background_id;
			if($this->check_background_status($background_id)){
				$this->head_output($background_id);
				return;
			}
		}else if(is_archive()){		
			$background_id = isset($options['archive'])?intval($options['archive']):0;
			if($this->check_background_status($background_id)){
				$this->head_output($background_id);
				return;
			}
			
			if(intval($background_id)==0){
				global $wp_version;
				if($wp_version>='3.1.0'&&isset($options['taxonomies'])&&is_array($options['taxonomies'])&&count($options['taxonomies'])>0){
					global $wp_query;
					$cat = $wp_query->get_queried_object();
					$args=array(
					   'post_type'=>'background',
					   'posts_per_page'=>4,
					   'post_status'=>'publish',
					   'tax_query'=>array(
					   	array('taxonomy'=>$cat->taxonomy,
						'field'=>'id',
						'terms'=>array($cat->term_id))
					   )
					);
					$backgrounds = new WP_Query($args);
					$k = 0;
					while($backgrounds->have_posts()) : $backgrounds->the_post();
						$background_id = get_the_ID();							
						if($this->check_background_status($background_id)){
							$this->head_output($background_id);
							return;
						}
					endwhile;																				
				}
			}
		}
		
		$background_id = isset($options['fallback'])?intval($options['fallback']):0;
		if($this->check_background_status($background_id)){
			$this->head_output($background_id);
			return;
		}		
	}
	
	function check_background_status($background_id){
		if($background_id>0){
			$b = get_post($background_id,'OBJECT');
			return $b->post_status == 'publish' && $b->post_type=='background' ;		
		}
		return false;
	}
	
	function update_cookie(){
?><script>try{var d = new Date();jQuery.cookie('cbg_tz', d.getTimezoneOffset(), { path: '/', expires: 366 });}catch(err){}</script><?php
	}

	function get_cbg_tz(){
		return isset($_COOKIE['cbg_tz'])?$_COOKIE['cbg_tz']:(isset($_REQUEST['cbg_tz'])?$_REQUEST['cbg_tz']:false);
	}
	
	function handle_local_time_zone(){
		if(false===$this->get_cbg_tz()){	
			$arr = parse_url($_SERVER['REQUEST_URI'])	;	
			$arr['query']=isset($arr['query'])?$arr['query']:'';
?>
<script language='javascript'>
var d = new Date();
location.href="<?php echo $arr['path']?>?cbg_tz=" + d.getTimezoneOffset() + "<?php echo ''==trim($arr['query'])?'':'&'.$arr['query']?>";
</script>
<?php		
			$url = $arr['path'].'?cbg_tz=0'.(''==trim($arr['query'])?'':'&'.$arr['query']);	
		    wp_die("If you dont get automatically redirected, <a href=\"$url\">click here</a>","Redirecting",array());
		}
	}
	
	function wp_footer(){
		echo $this->wp_footer;
	}
	
	function head_output($background_id,$skip=''){
		global $cbg_plugin;
		if($cbg_plugin->frontend_scripts_in_footer){
			ob_start();
			$this->_head_output($background_id,$skip);
			$this->wp_footer.=ob_get_contents();
			ob_end_clean();
		}else{
			return $this->_head_output($background_id,$skip);
		}
	}
	
	function _head_output($background_id,$skip=''){
		$options = get_option('custom_background_options');		
		if(isset($options['skip_handle_local_time_zone'])&&1==intval($options['skip_handle_local_time_zone'])){
			
		}else{
			$this->handle_local_time_zone();
		}

		global $wpdb;		
		$bg_ids = $wpdb->get_col("SELECT ID FROM $wpdb->posts WHERE post_parent=$background_id and post_type='background' and post_status='publish' ORDER BY menu_order",0);
		$bg_ids = is_array($bg_ids)?$bg_ids:array();
		array_unshift($bg_ids,$background_id);	
		echo "<script type='text/javascript'>var custback_url='".CUSTBACK_URL."';var bg_selectors = [];var bg_backgrounds = [];</script>";
		foreach($bg_ids as $background_id){
			//-------------

			$background_type = get_post_meta($background_id,'background_type',true);
			if($background_type=='bg-scheduled'){
				$this->handle_scheduled($this->bg_set,$background_id);	
				$this->extra_css($background_id);
				echo '<script>jQuery(document).ready(function($) {bg_scheduled_init('.$this->bg_set.');});</script>'; 	
			}elseif($background_type=='bg-change'){
				$this->handle_scheduled($this->bg_set,$background_id,'');	
				$this->extra_css($background_id);
				echo '<script>jQuery(document).ready(function($) {bg_change_init('.$this->bg_set.');});</script>';	
			}elseif($background_type=='bg-stretcher'){
				$this->handle_scheduled($this->bg_set,$background_id,'',false);	
				$this->extra_css($background_id);
				echo '<script>jQuery(document).ready(function($) {bg_stretcher_init('.$this->bg_set.','.$this->bg_stretcher_settings($background_id).');});</script>';	
			}elseif($background_type=='bg-parallax'){
				$this->handle_scheduled($this->bg_set,$background_id,'',false);	
				$this->extra_css($background_id);
				echo '<script>jQuery(document).ready(function($) {bg_parallax_init('.$this->bg_set.');});</script>';	
			}			
			//-------------
			$this->bg_set++;
		}
	}
	
	function bg_stretcher_settings($background_id){
		$option = get_post_meta($background_id,'cb_bgstretcher',true);
		$option = is_array($option)?$option:array();
		
		$option['bgst_nextSlideDelay']=isset($option['bgst_nextSlideDelay'])?$option['bgst_nextSlideDelay']*1000:3000;
		$option['bgst_slideShowSpeed']=isset($option['bgst_slideShowSpeed'])?$option['bgst_slideShowSpeed']*1000:3000;
		
		foreach(array('bgst_preloadImg'=>true,'bgst_resizeProportionally'=>true,'bgst_resizeAnimate'=>false,'bgst_slideShow'=>false) as $field => $value){
			$option[$field]=isset($option[$field])?($option[$field]==1?true:false):$value;
		}
				
		$arr = array();
		foreach($option as $field => $value){
			$name = str_replace('bgst_','',$field);
			$arr[$name]=$value;
		}	
		
		return json_encode((object)$arr);
	}
	
	function extra_css($background_id){
		$css = get_post_meta($background_id,'background-extra',true);	
		echo trim($css)==''?'':sprintf("<style type=\"text/css\" rel=\"custom-backgrounds\">\n/*extra css custom backgrounds*/\n%s</style>\n",$css);
	}
	
	function handle_scheduled($bg_set,$background_id,$important='!important',$echo=true){
		//------------------
		$args = array(
			'post_parent' => $background_id,
			'orderby'	=> 'menu_order',
			'order'=>'ASC'
		);		
		$attachments = get_cbg_attachments($args);
		if ($attachments) {
			$custom_background = "<style type=\"text/css\" rel=\"custom-backgrounds\">\n/* added by custom backgrounds plugin*/\n";
			$done_selectors = array();
			$all_backgrounds = array();
			foreach ($attachments as $attachment) {
				$tmp = '';
				$p = array();
				foreach(  array('background_selector','background_external_url','background_attachment','background_color','background_custom_color', 'background_x','background_y','background_position','background_repeat','background_size','background_size_width','background_size_height','date_from','date_to','time_from','time_to','background_interval','background_url','background_target','background_cursor','parallax_width','parallax_height','parallax_left','parallax_top') as $field){
					$p[$field] = get_post_meta($attachment->ID,$field,true);
				}
				
				if(''==trim($p['background_selector']))
					continue;
			
				//DATE Filter
				if(isset($_REQUEST['bgts'])){
					$now = strtotime($_REQUEST['bgts']);
				}else if(false!==$this->get_cbg_tz()){
					$now = gmmktime(gmdate("H"),gmdate("i")-$this->get_cbg_tz());
				}else{
					$now =mktime();
				}

				if(strlen($p['date_from'])==16){
					if($now<strtotime($p['date_from'],$now))
						continue;
				}
				if(strlen($p['date_to'])==16){
					if($now>strtotime($p['date_to'],$now))
						continue;
				}
				//--Time filter
				if(trim($p['time_from'])!=''){
					if($now<strtotime($p['time_from'],$now))
						continue;
				}
				if(trim($p['time_to'])!=''){
					if($now>strtotime($p['time_to'],$now))
						continue;
				}
				
				$p['background_image']= $attachment->post_type=='cbg-attachment'? $p['background_external_url'] : wp_get_attachment_url($attachment->ID);
				
				$all_backgrounds[]=(object)$p;
				
				//only load settings for the same selector once:
				if(in_array($p['background_selector'],$done_selectors)){
					continue;
				}
				//--- end of validations ---
				$done_selectors[]=$p['background_selector'];	
				//-----------
				$custom_background .= sprintf("%s {\n",$p['background_selector']);
				//----------------------------------------------------------
				//--- background-image
				if(trim($p['background_image'])==''){
					$custom_background.="\tbackground-image: none ;\n";
				}else{
					$custom_background.=sprintf("\tbackground-image: url('%s') %s;\n", $p['background_image'],$important );
				}
				//--- background-position
				if(''!=trim($p['background_position'])){
					if($p['background_position']=='x% y%' || $p['background_position']=='xpos ypos'){
						if(trim($p['background_x'])!='' && trim($p['background_y'])!=''){
							$custom_background.=sprintf("\tbackground-position: %s %s %s ;\n",$p['background_x'],$p['background_y'],$important);
						}
					}else{
						$custom_background.=sprintf("\tbackground-position: %s %s;\n",$p['background_position'],$important);
					}
				}		
				//--- background-color
				if(''!=trim($p['background_color'])){
					if($p['background_color']=='custom'){
						if(''!=trim($p['background_custom_color'])){
							$custom_background.=sprintf("\tbackground-color: %s %s;\n",$p['background_custom_color'],$important);
						}
					}else{
						$custom_background.=sprintf("\tbackground-color: %s %s;\n",$p['background_color'],$important);
					}
				}		
				//--- background-attachment and background-repeat
				foreach(array('background_attachment'=>'background-attachment','background_repeat'=>'background-repeat') as $field => $css_field){
					if(''!=trim($p[$field])){
						$custom_background.=sprintf("\t%s: %s %s;\n",$css_field,$p[$field],$important);
					}		
				}				
				//--- background-size
				if(''!=trim($p['background_size'])){
					if($p['background_size']=='percentage' || $p['background_size']=='length'){
						if(trim($p['background_size_width'])!='' && trim($p['background_size_height'])!=''){
							$custom_background.=sprintf("\tbackground-size: %s %s %s;\n",$p['background_size_width'],$p['background_size_height'],$important);
						}
					}else{
						$custom_background.=sprintf("\tbackground-size: %s %s;\n",$p['background_size'],$important);
					}
				}		
				//--- background cursor
				if(''!=trim($p['background_url']) && '1'==$p['background_cursor']){
					$custom_background.="\tcursor: pointer;\n";
				}		
				//----------------------------------------------------------
				$custom_background .= "}\n";
				//--- background cursor
				if(''!=trim($p['background_url']) && '1'==$p['background_cursor'] ){
					$custom_background .= sprintf("%s > * {\n",$p['background_selector']);
					$custom_background.="\tcursor: default;\n";
					$custom_background .= "}\n";
				}		
				//--------------
			}
			$custom_background.="</style>";
			echo "<script type='text/javascript' rel='custom-backgrounds'>\n";
			if(count($done_selectors)>0){
				echo "bg_selectors[$bg_set]=".json_encode($done_selectors).";\n";
			}
			if(count($all_backgrounds)>0){
				echo "bg_backgrounds[$bg_set]=".json_encode($all_backgrounds).";\n";
			}
			echo "</script>";
			if($echo)
				echo $custom_background;
		}	
		//------------------	
	}
	

}

new BackgroundsFrontend();
?>