<?php

class PostPageBackgrounds {
	var $capability = 'manage_backgroundproperties';
	var $options = array();
	function PostPageBackgrounds(){
		$this->options = get_option('custom_background_options');
		if(current_user_can('manage_options')||current_user_can($this->capability)){
			add_action('admin_menu', array(&$this, 'post_meta_box') );
			add_action('save_post', array(&$this,'save_post'), 10, 1 );
			
			if(isset($this->options['enable_quick_edit'])&&$this->options['enable_quick_edit']==1){
				add_action('quick_edit_custom_box', array(&$this,'quick_edit_custom_box'));
				
				add_filter('manage_posts_columns', array(&$this,'manage_posts_columns'), 10, 1);
				add_filter('manage_pages_columns', array(&$this,'manage_posts_columns'), 10, 1);
				
				add_action('manage_posts_custom_column', array(&$this,'custom_column'),10,2);	
				add_action('manage_pages_custom_column', array(&$this,'custom_column'),10,2);	
				
				add_filter('editable_slug', array(&$this,'editable_slug'),1000, 1);
			}
		}	
	}
	
	function post_type_enabled($post_type){
		return in_array( $post_type, array_merge((is_array($this->options['post_types'])?$this->options['post_types']:array()),array('page','post')) );
	}
	
	function editable_slug($str){
		global $post;
		if(is_object($post)&&property_exists($post,'post_type')&&!$this->post_type_enabled($post->post_type)) 
			return $str;
		foreach( debug_backtrace() as $bt ){
			if('get_inline_data'==$bt['function']){
				if(false===strpos($str,'custom_background')){
					$back_id = get_post_meta($post->ID,'custom-background',true);
					$back_id = trim($back_id)==''?'0':$back_id;
					return "$str</div>\r\n\t<div class=\"custom_background\">".$back_id;
				}			
			}
		}
		return $str;		
	}
	
	function custom_column($field, $post_id=null){
		global $post;
		$post_id = $post_id==null?$post->ID:$post_id;
		if($field=='custom-background'){
			
			$current = intval(get_post_meta($post_id,'custom-background',true));
			if($current==0){
				echo __("no custom background","cbw");
			}else{
				global $wpdb;
				$edit_link = get_edit_post_link( $current );
				$title = $wpdb->get_var("SELECT post_title FROM `{$wpdb->posts}` WHERE ID=$current",0,0);
				echo "<a href=\"$edit_link\">$title</a>";				
			}
		}
	}
	
	function manage_posts_columns($posts_columns){
		global $post;
		if(!$this->post_type_enabled($post->post_type)) 
			return $posts_columns;		
		$posts_columns['custom-background']=__('Background','cbw');
		return $posts_columns; 
	}
	
	function quick_edit_custom_box($column_name){
		global $post;
		if(!$this->post_type_enabled($post->post_type)) 
			return;	
		if(did_action('quick_edit_custom_box') === 1):
	
echo '<input type="hidden" name="custom_background_nonce" value="' . wp_create_nonce( 'custom_background_nonce' ) . '" />';	
?>
<div class="cbw-inline-cont">
<fieldset class="inline-edit-col-left">&nbsp;</fieldset>
<fieldset class="inline-edit-col-right">
    <div class="inline-edit-col">
		<span class="title">Background</span>
		<?php echo $this->get_background_dropdown($current,'custom_background','custom_background')?>
	</div>
</fieldset>
</div>
<?php
		endif;
	}
	
	function post_meta_box(){
		add_meta_box( 'custom-background', __('Custom background'),	array( &$this, 'form_template' ), 'page', 'side', 'default');
		add_meta_box( 'custom-background', __('Custom background'),	array( &$this, 'form_template' ), 'post', 'side', 'default');
		if(!empty($this->options['post_types'])&&count($this->options['post_types'])>0){
			foreach($this->options['post_types'] as $post_type){
				add_meta_box( 'custom-background', __('Custom background'),	array( &$this, 'form_template' ), $post_type, 'side', 'default');
			}
		}
	}	
	
	function save_post($post_id){	
		if ( !wp_verify_nonce( @$_POST['custom_background_nonce'], 'custom_background_nonce' )) {
			return $post_id;
		}
		if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
			return $post_id;
		// Check permissions
		if ( 'page' == $_POST['post_type'] ) {
		  if ( !current_user_can( 'edit_page', $post_id ) )
		    return $post_id;
		} else {
		  if ( !current_user_can( 'edit_post', $post_id ) )
		    return $post_id;
		}
		
		if(isset($_POST['custom_background'])){
			$_POST['custom-background']=$_POST['custom_background'];
		}
		
		foreach( array('custom-background') as $field){
			if(isset($_POST[$field])){
				update_post_meta($post_id,$field,$_POST[$field]);		
			}
		}
		return $post_id;
	}	

		
	function form_template($post){
		echo '<input type="hidden" name="custom_background_nonce" id="custom_background_nonce" value="' . wp_create_nonce( 'custom_background_nonce' ) . '" />';
		//----------------------
		$args=array(
		   'post_type'=>'background',
		   'posts_per_page'=>-1,//all
			'post_status'=>'publish'
		);

		$current = get_post_meta($post->ID,'custom-background',true);
		echo $this->get_background_dropdown($current);
	}	
	
	function get_background_dropdown($current,$id='custom-background',$name=null,$extra=''){
		global $wpdb;
		$name=null==$name?$id:$name;
		$str = "<select id=\"$id\" name=\"$name\" $extra>";
		$str.= "<option value=\"0\">-- no custom background --</option>";		
		
		$sql = "SELECT ID, post_title FROM `{$wpdb->posts}` WHERE post_type='background' and post_status='publish' ORDER BY post_title";
		if($wpdb->query($sql)&&$wpdb->num_rows>0){
			foreach($wpdb->last_result as $row){
				$selected = $current==$row->ID?'selected':'';
				$str.= sprintf('<option %s value="%s">%s</option>',$selected,$row->ID, $row->post_title );
			}
		}
		$str.= "</select>";
		return $str;		
	}
	
}

new PostPageBackgrounds();

?>